@@ -4,16 +4,19 @@
  *  for how to set the configuration options.
  */
 
-#undef  bool
+#include <ncurses.h>
 
-#include <curses.h>
-
-#ifdef C_PANELSUPPORT
+#ifdef C_PANELFUNCTION
 #include <panel.h>
 #endif
 
-#undef  instr
-#define instr _sigh_sigh_sigh_
+#ifdef C_MENUFUNCTION
+#include <menu.h>
+#endif
+
+#ifdef C_FORMFUNCTION
+#include <form.h>
+#endif
 
 #define C_LONGNAME
 #define C_LONG0ARGS
